@@ -101,6 +101,7 @@ CONFIG = [
     ("blog_feed_fulltext", False, True),
     ("blog_feed_subtitle", None, True),
     ("blog_feed_titles", None, False),
+    ("blog_feed_templates", {"atom": {}}, True),
     ("blog_feed_length", None, None),
     ("blog_authors", {}, True, require_config_full_name_link_dict()),
     ("blog_default_author", None, True, require_config_str_or_list_lookup("blog_authors")),
@@ -124,7 +125,6 @@ CONFIG = [
     ("blog_post_pattern", [], True, require_config_type((str, list))),
 ]
 
-
 TOMORROW = datetime.today() + dtmod.timedelta(1)
 TOMORROW = TOMORROW.replace(hour=0, minute=0, second=0, microsecond=0)
 FUTURE = datetime(9999, 12, 31)
@@ -153,7 +153,6 @@ def link_posts(posts):
 
 
 class Blog(Container):
-
     """
     Handle blog operations.
     """
@@ -244,7 +243,7 @@ class Blog(Container):
         try:
             attr = self.config[name]
         except KeyError:
-            raise AttributeError("ABlog has no configuration option {}".format(repr(name)))
+            raise AttributeError(f"ABlog has no configuration option {repr(name)}")
         return attr
 
     def __getitem__(self, key):
@@ -369,7 +368,6 @@ class BlogPageMixin:
 
 
 class Post(BlogPageMixin):
-
     """
     Handle post metadata.
     """
@@ -487,7 +485,6 @@ class Post(BlogPageMixin):
 
 
 class Catalog(BlogPageMixin):
-
     """
     Handles collections of posts.
     """
@@ -562,7 +559,6 @@ class Catalog(BlogPageMixin):
 
 
 class Collection(BlogPageMixin):
-
     """
     Posts sharing a label, i.e. tag, category, author, or location.
     """
