@@ -741,7 +741,10 @@ def generate_atom_feeds(app):
 
             # Entry values that support templates
             title = post.title
-            summary = " ".join(paragraph.astext() for paragraph in post.excerpt[0])
+            if post.excerpt:
+                summary = " ".join(paragraph.astext() for paragraph in post.excerpt[0])
+            else:
+                summary = ""
             template_values = {}
             for element in ("title", "summary", "content"):
                 if element in feed_templates:
